/**
 * @license
 * Copyright Jonathan Phillips (https://github.com/jphillips03) All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at
 * https://github.com/ngx-material-dashboard/ngx-material-dashboard/license
 */
import { OnInit } from '@angular/core';
import { MatDialogRef } from '@angular/material/dialog';
import { IconDefinition } from '@fortawesome/fontawesome-common-types';
import { DialogData } from '../../interfaces/dialog-data.interface';
import * as i0 from "@angular/core";
/**
 * A re-usable confirmation dialog with configurable title and text values. If
 * the user confirms in the dialog, then the result returned to the dialog
 * opener is `true`. This allows for complete control of deleting the thing
 * the user wants to delete.
 *
 * @overviewDetails
 * #### Basic Usage Example
 * ```typescript
 * import {Component} from '@angular/core';
 * import {MatDialog} from '@angular/material/dialog';
 *
 * @Component({
 *     selector: 'confirm-delete-dialog-usage-example',
 *     templateUrl: './confirm-delete-dialog-usage-example.html'
 * })
 * export class ConfirmDeleteDialogUsageExample {
 *
 *     constructor(private dialog: MatDialog) {}
 *
 *     // you will need to call this somewhere, either from a button `(click)`
 *     // event, or perhaps in a subscribe block to some observable
 *     openConfirmDeleteDialog(): void {
 *         // open the dialog
 *         const dialogRef = this.dialog.open(
 *             ConfirmDeleteDialogComponent,
 *             {data: {context:'Are you sure you want to delete value?', title:'Delete value?'}}
 *         );
 *
 *         // handle when dialog closed
 *         dialogRef.afterClosed().subscribe((confirm: boolean) => {
 *             if (confirm) {
 *                 // logic to delete the thing
 *             } // if no confirmation then nothing to do
 *         });
 *     }
 * }
 * ```
 */
export declare class ConfirmDeleteDialogComponent implements OnInit {
    private dialogRef;
    private data;
    /** The icon to render in the dialog. */
    faTrash: IconDefinition;
    /** The title to display in the dialog. */
    title: string;
    /** The main content of the dialog. */
    content: string;
    constructor(dialogRef: MatDialogRef<ConfirmDeleteDialogComponent>, data: DialogData);
    ngOnInit(): void;
    /**
     * Closes the dialog without returning any value so dialog opener can
     * safely ignore the initial delete request.
     */
    cancel(): void;
    /**
     * Closes the dialog and returns `true` to the dialog opener so it can
     * handle the logic to delete the thing.
     */
    delete(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ConfirmDeleteDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ConfirmDeleteDialogComponent, "ngx-mat-confirm-delete-dialog", never, {}, {}, never, never>;
}
